pytomography.transforms.transform — PyTomography 0.8.0 documentation

Skip to main content
`Ctrl`+`K`

# `pytomography.transforms.transform`

## Module Contents

### Classes

`Transform` | The parent class for all transforms used in reconstruction (obj2obj, im2im, obj2im). Subclasses must implement the `__call__` method.

class pytomography.transforms.transform.Transform

  The parent class for all transforms used in reconstruction (obj2obj, im2im, obj2im). Subclasses must implement the `__call__` method.

  Parameters:

    device (str) – Pytorch device used for computation

  configure(object_meta, image_meta)

    Configures the transform to the object/image metadata. This is done after creating the network so that it can be adjusted to the system matrix.

    Parameters:

      - object_meta (ObjectMeta) – Object metadata.

      - image_meta (ImageMeta) – Image metadata.

    Return type:

      None

  abstract forward(x)

    Abstract method; must be implemented in subclasses to apply a correction to an object/image and return it

    Parameters:

      x (torch.tensor) –

  abstract backward(x)

    Abstract method; must be implemented in subclasses to apply a correction to an object/image and return it

    Parameters:

      x (torch.tensor) –